@@ -3,6 +3,9 @@ import logging
 
 _LOGGER = logging.getLogger("pyecobee")
 
+ECOBEE_USERNAME = "USERNAME"
+ECOBEE_PASSWORD = "PASSWORD"
+
 ECOBEE_ACCESS_TOKEN = "ACCESS_TOKEN"
 ECOBEE_API_KEY = "API_KEY"
 ECOBEE_AUTHORIZATION_CODE = "AUTHORIZATION_CODE"
